Cydra
=====

Cydra is a platform for project hosting written in Python. It has an 
extensible architecture to facilitate integration of 3rd party software 
such as version control systems and project management tools.

Cydra is ideal for organizations wishing to provide code hosting facilities 
for their users. Projects and repositories can be created via the built-in 
web interface. 